@@ -28,8 +28,6 @@ pub enum Error {
     Decryption(#[source] BlockModeError),
     #[error(display = "A generic I/O error")]
     Io(#[source] IoError),
-    #[error(display = "Too few bytes were decrypted ({}), expected {}", _0, _1)]
-    TooFewBytesDecrypted(usize, usize),
     #[error(display = "Generic error({})", _0)]
     Generic(String),
     #[error(display = "Serialisation error")]
